# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arg_services/graph/v1/graph.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='arg_services/graph/v1/graph.proto',
  package='arg_services.graph.v1',
  syntax='proto3',
  serialized_options=b'\n(de.uni_trier.recap.arg_services.graph.v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!arg_services/graph/v1/graph.proto\x12\x15\x61rg_services.graph.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa0\x06\n\x05Graph\x12\x36\n\x05nodes\x18\x02 \x03(\x0b\x32\'.arg_services.graph.v1.Graph.NodesEntry\x12\x36\n\x05\x65\x64ges\x18\x03 \x03(\x0b\x32\'.arg_services.graph.v1.Graph.EdgesEntry\x12>\n\tresources\x18\x04 \x03(\x0b\x32+.arg_services.graph.v1.Graph.ResourcesEntry\x12\x44\n\x0cparticipants\x18\x05 \x03(\x0b\x32..arg_services.graph.v1.Graph.ParticipantsEntry\x12\x13\n\x0bmajor_claim\x18\x06 \x01(\t\x12\x34\n\x08\x61nalysts\x18\x07 \x03(\x0b\x32\".arg_services.graph.v1.Participant\x12\x0f\n\x07version\x18\x08 \x01(\t\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x1aI\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.arg_services.graph.v1.Node:\x02\x38\x01\x1aI\n\nEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.arg_services.graph.v1.Edge:\x02\x38\x01\x1aQ\n\x0eResourcesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.arg_services.graph.v1.Resource:\x02\x38\x01\x1aW\n\x11ParticipantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".arg_services.graph.v1.Participant:\x02\x38\x01\"\xbc\x01\n\x08Resource\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\"\xf5\x01\n\x0bParticipant\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\"\xab\x01\n\x04\x45\x64ge\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\"\xf9\x01\n\x04Node\x12/\n\x04\x61tom\x18\x02 \x01(\x0b\x32\x1f.arg_services.graph.v1.AtomNodeH\x00\x12\x33\n\x06scheme\x18\x03 \x01(\x0b\x32!.arg_services.graph.v1.SchemeNodeH\x00\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.StructB\x06\n\x04node\"b\n\x08\x41tomNode\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x33\n\treference\x18\x03 \x01(\x0b\x32 .arg_services.graph.v1.Reference\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\"\xa8\x01\n\nSchemeNode\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.arg_services.graph.v1.SchemeType\x12;\n\x14\x61rgumentation_scheme\x18\x03 \x01(\x0e\x32\x1d.arg_services.graph.v1.Scheme\x12,\n\x0b\x64\x65scriptors\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\tReference\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\x12\x0c\n\x04text\x18\x04 \x01(\t\x12)\n\x08metadata\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct*\xd8\x15\n\x06Scheme\x12\x16\n\x12SCHEME_UNSPECIFIED\x10\x00\x12\x15\n\x11SCHEME_AD_HOMINEM\x10\x01\x12\x1c\n\x18SCHEME_ALTERNATIVE_MEANS\x10\x02\x12\x17\n\x13SCHEME_ALTERNATIVES\x10\x03\x12\x12\n\x0eSCHEME_ANALOGY\x10\x04\x12*\n&SCHEME_ARBITRARY_VERBAL_CLASSIFICATION\x10\x05\x12\x14\n\x10SCHEME_AUTHORITY\x10\x06\x12\x0f\n\x0bSCHEME_BIAS\x10\x07\x12 \n\x1cSCHEME_BIASED_CLASSIFICATION\x10\x08\x12\x16\n\x12SCHEME_CALLING_OUT\x10\t\x12 \n\x1cSCHEME_CAUSAL_SLIPPERY_SLOPE\x10\n\x12\x1a\n\x16SCHEME_CAUSE_TO_EFFECT\x10\x0b\x12$\n SCHEME_CIRCUMSTANTIAL_AD_HOMINEM\x10\x0c\x12\x1f\n\x1bSCHEME_COMMITMENT_EXCEPTION\x10\r\x12\x15\n\x11SCHEME_COMMITMENT\x10\x0e\x12\x16\n\x12SCHEME_COMPOSITION\x10\x0f\x12\x1c\n\x18SCHEME_CONFLICTING_GOALS\x10\x10\x12\x17\n\x13SCHEME_CONSEQUENCES\x10\x11\x12\x1f\n\x1bSCHEME_CORRELATION_TO_CAUSE\x10\x12\x12\x18\n\x14SCHEME_DANGER_APPEAL\x10\x13\x12.\n*SCHEME_DEFINITION_TO_VERBAL_CLASSIFICATION\x10\x14\x12+\n\'SCHEME_DIFFERENCES_UNDERMINE_SIMILARITY\x10\x15\x12\x12\n\x0eSCHEME_DILEMMA\x10\x16\x12\x1c\n\x18SCHEME_DIRECT_AD_HOMINEM\x10\x17\x12\x13\n\x0fSCHEME_DIVISION\x10\x18\x12\x1b\n\x17SCHEME_ESTABLISHED_RULE\x10\x19\x12\x12\n\x0eSCHEME_ETHOTIC\x10\x1a\x12!\n\x1dSCHEME_EVIDENCE_TO_HYPOTHESIS\x10\x1b\x12\x12\n\x0eSCHEME_EXAMPLE\x10\x1c\x12$\n SCHEME_EXCEPTION_SIMILARITY_CASE\x10\x1d\x12\x1b\n\x17SCHEME_EXCEPTIONAL_CASE\x10\x1e\x12\x19\n\x15SCHEME_EXPERT_OPINION\x10\x1f\x12\"\n\x1eSCHEME_EXPERTISE_INCONSISTENCY\x10 \x12\x13\n\x0fSCHEME_FAIRNESS\x10!\x12&\n\"SCHEME_FALSIFICATION_OF_HYPOTHESIS\x10\"\x12\x16\n\x12SCHEME_FEAR_APPEAL\x10#\x12\x1e\n\x1aSCHEME_FULL_SLIPPERY_SLOPE\x10$\x12#\n\x1fSCHEME_GENERAL_ACCEPTANCE_DOUBT\x10%\x12\x1d\n\x19SCHEME_GENERIC_AD_HOMINEM\x10&\x12\x13\n\x0fSCHEME_GOODWILL\x10\'\x12\x15\n\x11SCHEME_GRADUALISM\x10(\x12\x14\n\x10SCHEME_IGNORANCE\x10)\x12\"\n\x1eSCHEME_INCONSISTENT_COMMITMENT\x10*\x12\x1b\n\x17SCHEME_INFORMANT_REPORT\x10+\x12(\n$SCHEME_INTERACTION_OF_ACT_AND_PERSON\x10,\x12!\n\x1dSCHEME_IRRATIONAL_FEAR_APPEAL\x10-\x12%\n!SCHEME_LACK_OF_COMPLETE_KNOWLEDGE\x10.\x12%\n!SCHEME_LACK_OF_EXPERT_RELIABILITY\x10/\x12\x12\n\x0eSCHEME_LOGICAL\x10\x30\x12\x1f\n\x1bSCHEME_MISPLACED_PRIORITIES\x10\x31\x12\x17\n\x13SCHEME_MODUS_PONENS\x10\x32\x12\x17\n\x13SCHEME_MORAL_VIRTUE\x10\x33\x12\x18\n\x14SCHEME_NEED_FOR_HELP\x10\x34\x12 \n\x1cSCHEME_NEGATIVE_CONSEQUENCES\x10\x35\x12\x1d\n\x19SCHEME_OPPOSED_COMMITMENT\x10\x36\x12\x16\n\x12SCHEME_OPPOSITIONS\x10\x37\x12\"\n\x1eSCHEME_CAUSAL_FACTORS_INVOLVED\x10\x38\x12\x15\n\x11SCHEME_PARAPHRASE\x10\x39\x12\x15\n\x11SCHEME_PERCEPTION\x10:\x12\x1a\n\x16SCHEME_POPULAR_OPINION\x10;\x12\x1b\n\x17SCHEME_POPULAR_PRACTICE\x10<\x12\x1b\n\x17SCHEME_POSITION_TO_KNOW\x10=\x12 \n\x1cSCHEME_POSITIVE_CONSEQUENCES\x10>\x12+\n\'SCHEME_PRACTICAL_REASONING_FROM_ANALOGY\x10?\x12\x1e\n\x1aSCHEME_PRACTICAL_REASONING\x10@\x12\x1b\n\x17SCHEME_PRACTICAL_WISDOM\x10\x41\x12!\n\x1dSCHEME_PRAGMATIC_ALTERNATIVES\x10\x42\x12\"\n\x1eSCHEME_PRAGMATIC_INCONSISTENCY\x10\x43\x12#\n\x1fSCHEME_PRECEDENT_SLIPPERY_SLOPE\x10\x44\x12 \n\x1cSCHEME_PROPERTY_NOT_EXISTANT\x10\x45\x12\x14\n\x10SCHEME_REFRAMING\x10\x46\x12\x19\n\x15SCHEME_REQUIRED_STEPS\x10G\x12\"\n\x1eSCHEME_RESOLVING_INCONSISTENCY\x10H\x12\x0f\n\x0bSCHEME_RULE\x10I\x12\x10\n\x0cSCHEME_RULES\x10J\x12!\n\x1dSCHEME_SIGN_FROM_OTHER_EVENTS\x10K\x12\x0f\n\x0bSCHEME_SIGN\x10L\x12)\n%SCHEME_TWO_PERSON_PRACTICAL_REASONING\x10M\x12\x15\n\x11SCHEME_UNFAIRNESS\x10N\x12&\n\"SCHEME_VAGUE_VERBAL_CLASSIFICATION\x10O\x12-\n)SCHEME_VAGUENESS_OF_VERBAL_CLASSIFICATION\x10P\x12*\n&SCHEME_VALUE_BASED_PRACTICAL_REASONING\x10Q\x12\x11\n\rSCHEME_VALUES\x10R\x12 \n\x1cSCHEME_VERBAL_CLASSIFICATION\x10S\x12 \n\x1cSCHEME_VERBAL_SLIPPERY_SLOPE\x10T\x12\x1a\n\x16SCHEME_VESTED_INTEREST\x10U\x12\x1a\n\x16SCHEME_VIRTUE_GOODWILL\x10V\x12\x10\n\x0cSCHEME_WASTE\x10W\x12\x17\n\x13SCHEME_WEAKEST_LINK\x10X\x12\x1a\n\x16SCHEME_WISDOM_GOODWILL\x10Y\x12\x18\n\x14SCHEME_WISDOM_VIRTUE\x10Z\x12!\n\x1dSCHEME_WISDOM_VIRTUE_GOODWILL\x10[\x12\x1c\n\x18SCHEME_WITNESS_TESTIMONY\x10\\*\xc7\x01\n\nSchemeType\x12\x1b\n\x17SCHEME_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SCHEME_TYPE_SUPPORT\x10\x01\x12\x16\n\x12SCHEME_TYPE_ATTACK\x10\x02\x12\x18\n\x14SCHEME_TYPE_REPHRASE\x10\x03\x12\x1a\n\x16SCHEME_TYPE_TRANSITION\x10\x04\x12\x1a\n\x16SCHEME_TYPE_PREFERENCE\x10\x05\x12\x19\n\x15SCHEME_TYPE_ASSERTION\x10\x06\x42*\n(de.uni_trier.recap.arg_services.graph.v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])

_SCHEME = _descriptor.EnumDescriptor(
  name='Scheme',
  full_name='arg_services.graph.v1.Scheme',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEME_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_AD_HOMINEM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ALTERNATIVE_MEANS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ALTERNATIVES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ANALOGY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ARBITRARY_VERBAL_CLASSIFICATION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_AUTHORITY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_BIAS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_BIASED_CLASSIFICATION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CALLING_OUT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CAUSAL_SLIPPERY_SLOPE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CAUSE_TO_EFFECT', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CIRCUMSTANTIAL_AD_HOMINEM', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_COMMITMENT_EXCEPTION', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_COMMITMENT', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_COMPOSITION', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CONFLICTING_GOALS', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CONSEQUENCES', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CORRELATION_TO_CAUSE', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DANGER_APPEAL', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DEFINITION_TO_VERBAL_CLASSIFICATION', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DIFFERENCES_UNDERMINE_SIMILARITY', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DILEMMA', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DIRECT_AD_HOMINEM', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_DIVISION', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ESTABLISHED_RULE', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_ETHOTIC', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EVIDENCE_TO_HYPOTHESIS', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EXAMPLE', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EXCEPTION_SIMILARITY_CASE', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EXCEPTIONAL_CASE', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EXPERT_OPINION', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_EXPERTISE_INCONSISTENCY', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_FAIRNESS', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_FALSIFICATION_OF_HYPOTHESIS', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_FEAR_APPEAL', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_FULL_SLIPPERY_SLOPE', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_GENERAL_ACCEPTANCE_DOUBT', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_GENERIC_AD_HOMINEM', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_GOODWILL', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_GRADUALISM', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_IGNORANCE', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_INCONSISTENT_COMMITMENT', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_INFORMANT_REPORT', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_INTERACTION_OF_ACT_AND_PERSON', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_IRRATIONAL_FEAR_APPEAL', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_LACK_OF_COMPLETE_KNOWLEDGE', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_LACK_OF_EXPERT_RELIABILITY', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_LOGICAL', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_MISPLACED_PRIORITIES', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_MODUS_PONENS', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_MORAL_VIRTUE', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_NEED_FOR_HELP', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_NEGATIVE_CONSEQUENCES', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_OPPOSED_COMMITMENT', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_OPPOSITIONS', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_CAUSAL_FACTORS_INVOLVED', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PARAPHRASE', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PERCEPTION', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_POPULAR_OPINION', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_POPULAR_PRACTICE', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_POSITION_TO_KNOW', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_POSITIVE_CONSEQUENCES', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRACTICAL_REASONING_FROM_ANALOGY', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRACTICAL_REASONING', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRACTICAL_WISDOM', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRAGMATIC_ALTERNATIVES', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRAGMATIC_INCONSISTENCY', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PRECEDENT_SLIPPERY_SLOPE', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_PROPERTY_NOT_EXISTANT', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_REFRAMING', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_REQUIRED_STEPS', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_RESOLVING_INCONSISTENCY', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_RULE', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_RULES', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_SIGN_FROM_OTHER_EVENTS', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_SIGN', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TWO_PERSON_PRACTICAL_REASONING', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_UNFAIRNESS', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VAGUE_VERBAL_CLASSIFICATION', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VAGUENESS_OF_VERBAL_CLASSIFICATION', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VALUE_BASED_PRACTICAL_REASONING', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VALUES', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VERBAL_CLASSIFICATION', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VERBAL_SLIPPERY_SLOPE', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VESTED_INTEREST', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_VIRTUE_GOODWILL', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WASTE', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WEAKEST_LINK', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WISDOM_GOODWILL', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WISDOM_VIRTUE', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WISDOM_VIRTUE_GOODWILL', index=91, number=91,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_WITNESS_TESTIMONY', index=92, number=92,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2167,
  serialized_end=4943,
)
_sym_db.RegisterEnumDescriptor(_SCHEME)

Scheme = enum_type_wrapper.EnumTypeWrapper(_SCHEME)
_SCHEMETYPE = _descriptor.EnumDescriptor(
  name='SchemeType',
  full_name='arg_services.graph.v1.SchemeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_SUPPORT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_ATTACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_REPHRASE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_TRANSITION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_PREFERENCE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEME_TYPE_ASSERTION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4946,
  serialized_end=5145,
)
_sym_db.RegisterEnumDescriptor(_SCHEMETYPE)

SchemeType = enum_type_wrapper.EnumTypeWrapper(_SCHEMETYPE)
SCHEME_UNSPECIFIED = 0
SCHEME_AD_HOMINEM = 1
SCHEME_ALTERNATIVE_MEANS = 2
SCHEME_ALTERNATIVES = 3
SCHEME_ANALOGY = 4
SCHEME_ARBITRARY_VERBAL_CLASSIFICATION = 5
SCHEME_AUTHORITY = 6
SCHEME_BIAS = 7
SCHEME_BIASED_CLASSIFICATION = 8
SCHEME_CALLING_OUT = 9
SCHEME_CAUSAL_SLIPPERY_SLOPE = 10
SCHEME_CAUSE_TO_EFFECT = 11
SCHEME_CIRCUMSTANTIAL_AD_HOMINEM = 12
SCHEME_COMMITMENT_EXCEPTION = 13
SCHEME_COMMITMENT = 14
SCHEME_COMPOSITION = 15
SCHEME_CONFLICTING_GOALS = 16
SCHEME_CONSEQUENCES = 17
SCHEME_CORRELATION_TO_CAUSE = 18
SCHEME_DANGER_APPEAL = 19
SCHEME_DEFINITION_TO_VERBAL_CLASSIFICATION = 20
SCHEME_DIFFERENCES_UNDERMINE_SIMILARITY = 21
SCHEME_DILEMMA = 22
SCHEME_DIRECT_AD_HOMINEM = 23
SCHEME_DIVISION = 24
SCHEME_ESTABLISHED_RULE = 25
SCHEME_ETHOTIC = 26
SCHEME_EVIDENCE_TO_HYPOTHESIS = 27
SCHEME_EXAMPLE = 28
SCHEME_EXCEPTION_SIMILARITY_CASE = 29
SCHEME_EXCEPTIONAL_CASE = 30
SCHEME_EXPERT_OPINION = 31
SCHEME_EXPERTISE_INCONSISTENCY = 32
SCHEME_FAIRNESS = 33
SCHEME_FALSIFICATION_OF_HYPOTHESIS = 34
SCHEME_FEAR_APPEAL = 35
SCHEME_FULL_SLIPPERY_SLOPE = 36
SCHEME_GENERAL_ACCEPTANCE_DOUBT = 37
SCHEME_GENERIC_AD_HOMINEM = 38
SCHEME_GOODWILL = 39
SCHEME_GRADUALISM = 40
SCHEME_IGNORANCE = 41
SCHEME_INCONSISTENT_COMMITMENT = 42
SCHEME_INFORMANT_REPORT = 43
SCHEME_INTERACTION_OF_ACT_AND_PERSON = 44
SCHEME_IRRATIONAL_FEAR_APPEAL = 45
SCHEME_LACK_OF_COMPLETE_KNOWLEDGE = 46
SCHEME_LACK_OF_EXPERT_RELIABILITY = 47
SCHEME_LOGICAL = 48
SCHEME_MISPLACED_PRIORITIES = 49
SCHEME_MODUS_PONENS = 50
SCHEME_MORAL_VIRTUE = 51
SCHEME_NEED_FOR_HELP = 52
SCHEME_NEGATIVE_CONSEQUENCES = 53
SCHEME_OPPOSED_COMMITMENT = 54
SCHEME_OPPOSITIONS = 55
SCHEME_CAUSAL_FACTORS_INVOLVED = 56
SCHEME_PARAPHRASE = 57
SCHEME_PERCEPTION = 58
SCHEME_POPULAR_OPINION = 59
SCHEME_POPULAR_PRACTICE = 60
SCHEME_POSITION_TO_KNOW = 61
SCHEME_POSITIVE_CONSEQUENCES = 62
SCHEME_PRACTICAL_REASONING_FROM_ANALOGY = 63
SCHEME_PRACTICAL_REASONING = 64
SCHEME_PRACTICAL_WISDOM = 65
SCHEME_PRAGMATIC_ALTERNATIVES = 66
SCHEME_PRAGMATIC_INCONSISTENCY = 67
SCHEME_PRECEDENT_SLIPPERY_SLOPE = 68
SCHEME_PROPERTY_NOT_EXISTANT = 69
SCHEME_REFRAMING = 70
SCHEME_REQUIRED_STEPS = 71
SCHEME_RESOLVING_INCONSISTENCY = 72
SCHEME_RULE = 73
SCHEME_RULES = 74
SCHEME_SIGN_FROM_OTHER_EVENTS = 75
SCHEME_SIGN = 76
SCHEME_TWO_PERSON_PRACTICAL_REASONING = 77
SCHEME_UNFAIRNESS = 78
SCHEME_VAGUE_VERBAL_CLASSIFICATION = 79
SCHEME_VAGUENESS_OF_VERBAL_CLASSIFICATION = 80
SCHEME_VALUE_BASED_PRACTICAL_REASONING = 81
SCHEME_VALUES = 82
SCHEME_VERBAL_CLASSIFICATION = 83
SCHEME_VERBAL_SLIPPERY_SLOPE = 84
SCHEME_VESTED_INTEREST = 85
SCHEME_VIRTUE_GOODWILL = 86
SCHEME_WASTE = 87
SCHEME_WEAKEST_LINK = 88
SCHEME_WISDOM_GOODWILL = 89
SCHEME_WISDOM_VIRTUE = 90
SCHEME_WISDOM_VIRTUE_GOODWILL = 91
SCHEME_WITNESS_TESTIMONY = 92
SCHEME_TYPE_UNSPECIFIED = 0
SCHEME_TYPE_SUPPORT = 1
SCHEME_TYPE_ATTACK = 2
SCHEME_TYPE_REPHRASE = 3
SCHEME_TYPE_TRANSITION = 4
SCHEME_TYPE_PREFERENCE = 5
SCHEME_TYPE_ASSERTION = 6



_GRAPH_NODESENTRY = _descriptor.Descriptor(
  name='NodesEntry',
  full_name='arg_services.graph.v1.Graph.NodesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.graph.v1.Graph.NodesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.graph.v1.Graph.NodesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=677,
)

_GRAPH_EDGESENTRY = _descriptor.Descriptor(
  name='EdgesEntry',
  full_name='arg_services.graph.v1.Graph.EdgesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.graph.v1.Graph.EdgesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.graph.v1.Graph.EdgesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=752,
)

_GRAPH_RESOURCESENTRY = _descriptor.Descriptor(
  name='ResourcesEntry',
  full_name='arg_services.graph.v1.Graph.ResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.graph.v1.Graph.ResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.graph.v1.Graph.ResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=835,
)

_GRAPH_PARTICIPANTSENTRY = _descriptor.Descriptor(
  name='ParticipantsEntry',
  full_name='arg_services.graph.v1.Graph.ParticipantsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='arg_services.graph.v1.Graph.ParticipantsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='arg_services.graph.v1.Graph.ParticipantsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=837,
  serialized_end=924,
)

_GRAPH = _descriptor.Descriptor(
  name='Graph',
  full_name='arg_services.graph.v1.Graph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='arg_services.graph.v1.Graph.nodes', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edges', full_name='arg_services.graph.v1.Graph.edges', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='arg_services.graph.v1.Graph.resources', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participants', full_name='arg_services.graph.v1.Graph.participants', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_claim', full_name='arg_services.graph.v1.Graph.major_claim', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysts', full_name='arg_services.graph.v1.Graph.analysts', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='arg_services.graph.v1.Graph.version', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='arg_services.graph.v1.Graph.created', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='arg_services.graph.v1.Graph.updated', index=8,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Graph.metadata', index=9,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRAPH_NODESENTRY, _GRAPH_EDGESENTRY, _GRAPH_RESOURCESENTRY, _GRAPH_PARTICIPANTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=924,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='arg_services.graph.v1.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.graph.v1.Resource.text', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='arg_services.graph.v1.Resource.title', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='arg_services.graph.v1.Resource.source', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='arg_services.graph.v1.Resource.created', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='arg_services.graph.v1.Resource.updated', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Resource.metadata', index=5,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1115,
)


_PARTICIPANT = _descriptor.Descriptor(
  name='Participant',
  full_name='arg_services.graph.v1.Participant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='arg_services.graph.v1.Participant.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='arg_services.graph.v1.Participant.username', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='arg_services.graph.v1.Participant.email', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='arg_services.graph.v1.Participant.url', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='arg_services.graph.v1.Participant.location', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='arg_services.graph.v1.Participant.description', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='arg_services.graph.v1.Participant.created', index=6,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='arg_services.graph.v1.Participant.updated', index=7,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Participant.metadata', index=8,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1363,
)


_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='arg_services.graph.v1.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='arg_services.graph.v1.Edge.source', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='arg_services.graph.v1.Edge.target', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='arg_services.graph.v1.Edge.created', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='arg_services.graph.v1.Edge.updated', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Edge.metadata', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1537,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='arg_services.graph.v1.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='atom', full_name='arg_services.graph.v1.Node.atom', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='arg_services.graph.v1.Node.scheme', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='arg_services.graph.v1.Node.created', index=2,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated', full_name='arg_services.graph.v1.Node.updated', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Node.metadata', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='arg_services.graph.v1.Node.node',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1540,
  serialized_end=1789,
)


_ATOMNODE = _descriptor.Descriptor(
  name='AtomNode',
  full_name='arg_services.graph.v1.AtomNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.graph.v1.AtomNode.text', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='arg_services.graph.v1.AtomNode.reference', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant', full_name='arg_services.graph.v1.AtomNode.participant', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1791,
  serialized_end=1889,
)


_SCHEMENODE = _descriptor.Descriptor(
  name='SchemeNode',
  full_name='arg_services.graph.v1.SchemeNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='arg_services.graph.v1.SchemeNode.type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='argumentation_scheme', full_name='arg_services.graph.v1.SchemeNode.argumentation_scheme', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptors', full_name='arg_services.graph.v1.SchemeNode.descriptors', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=2060,
)


_REFERENCE = _descriptor.Descriptor(
  name='Reference',
  full_name='arg_services.graph.v1.Reference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='arg_services.graph.v1.Reference.resource', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='arg_services.graph.v1.Reference.offset', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='arg_services.graph.v1.Reference.text', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='arg_services.graph.v1.Reference.metadata', index=3,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2164,
)

_GRAPH_NODESENTRY.fields_by_name['value'].message_type = _NODE
_GRAPH_NODESENTRY.containing_type = _GRAPH
_GRAPH_EDGESENTRY.fields_by_name['value'].message_type = _EDGE
_GRAPH_EDGESENTRY.containing_type = _GRAPH
_GRAPH_RESOURCESENTRY.fields_by_name['value'].message_type = _RESOURCE
_GRAPH_RESOURCESENTRY.containing_type = _GRAPH
_GRAPH_PARTICIPANTSENTRY.fields_by_name['value'].message_type = _PARTICIPANT
_GRAPH_PARTICIPANTSENTRY.containing_type = _GRAPH
_GRAPH.fields_by_name['nodes'].message_type = _GRAPH_NODESENTRY
_GRAPH.fields_by_name['edges'].message_type = _GRAPH_EDGESENTRY
_GRAPH.fields_by_name['resources'].message_type = _GRAPH_RESOURCESENTRY
_GRAPH.fields_by_name['participants'].message_type = _GRAPH_PARTICIPANTSENTRY
_GRAPH.fields_by_name['analysts'].message_type = _PARTICIPANT
_GRAPH.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GRAPH.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GRAPH.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RESOURCE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESOURCE.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESOURCE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PARTICIPANT.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANT.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANT.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_EDGE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EDGE.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EDGE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NODE.fields_by_name['atom'].message_type = _ATOMNODE
_NODE.fields_by_name['scheme'].message_type = _SCHEMENODE
_NODE.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODE.fields_by_name['updated'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NODE.oneofs_by_name['node'].fields.append(
  _NODE.fields_by_name['atom'])
_NODE.fields_by_name['atom'].containing_oneof = _NODE.oneofs_by_name['node']
_NODE.oneofs_by_name['node'].fields.append(
  _NODE.fields_by_name['scheme'])
_NODE.fields_by_name['scheme'].containing_oneof = _NODE.oneofs_by_name['node']
_ATOMNODE.fields_by_name['reference'].message_type = _REFERENCE
_SCHEMENODE.fields_by_name['type'].enum_type = _SCHEMETYPE
_SCHEMENODE.fields_by_name['argumentation_scheme'].enum_type = _SCHEME
_SCHEMENODE.fields_by_name['descriptors'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_REFERENCE.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['Graph'] = _GRAPH
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
DESCRIPTOR.message_types_by_name['Participant'] = _PARTICIPANT
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['AtomNode'] = _ATOMNODE
DESCRIPTOR.message_types_by_name['SchemeNode'] = _SCHEMENODE
DESCRIPTOR.message_types_by_name['Reference'] = _REFERENCE
DESCRIPTOR.enum_types_by_name['Scheme'] = _SCHEME
DESCRIPTOR.enum_types_by_name['SchemeType'] = _SCHEMETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Graph = _reflection.GeneratedProtocolMessageType('Graph', (_message.Message,), {

  'NodesEntry' : _reflection.GeneratedProtocolMessageType('NodesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GRAPH_NODESENTRY,
    '__module__' : 'arg_services.graph.v1.graph_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Graph.NodesEntry)
    })
  ,

  'EdgesEntry' : _reflection.GeneratedProtocolMessageType('EdgesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GRAPH_EDGESENTRY,
    '__module__' : 'arg_services.graph.v1.graph_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Graph.EdgesEntry)
    })
  ,

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GRAPH_RESOURCESENTRY,
    '__module__' : 'arg_services.graph.v1.graph_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Graph.ResourcesEntry)
    })
  ,

  'ParticipantsEntry' : _reflection.GeneratedProtocolMessageType('ParticipantsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GRAPH_PARTICIPANTSENTRY,
    '__module__' : 'arg_services.graph.v1.graph_pb2'
    # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Graph.ParticipantsEntry)
    })
  ,
  'DESCRIPTOR' : _GRAPH,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Graph)
  })
_sym_db.RegisterMessage(Graph)
_sym_db.RegisterMessage(Graph.NodesEntry)
_sym_db.RegisterMessage(Graph.EdgesEntry)
_sym_db.RegisterMessage(Graph.ResourcesEntry)
_sym_db.RegisterMessage(Graph.ParticipantsEntry)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

Participant = _reflection.GeneratedProtocolMessageType('Participant', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANT,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Participant)
  })
_sym_db.RegisterMessage(Participant)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), {
  'DESCRIPTOR' : _EDGE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Edge)
  })
_sym_db.RegisterMessage(Edge)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Node)
  })
_sym_db.RegisterMessage(Node)

AtomNode = _reflection.GeneratedProtocolMessageType('AtomNode', (_message.Message,), {
  'DESCRIPTOR' : _ATOMNODE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.AtomNode)
  })
_sym_db.RegisterMessage(AtomNode)

SchemeNode = _reflection.GeneratedProtocolMessageType('SchemeNode', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMENODE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.SchemeNode)
  })
_sym_db.RegisterMessage(SchemeNode)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE,
  '__module__' : 'arg_services.graph.v1.graph_pb2'
  # @@protoc_insertion_point(class_scope:arg_services.graph.v1.Reference)
  })
_sym_db.RegisterMessage(Reference)


DESCRIPTOR._options = None
_GRAPH_NODESENTRY._options = None
_GRAPH_EDGESENTRY._options = None
_GRAPH_RESOURCESENTRY._options = None
_GRAPH_PARTICIPANTSENTRY._options = None
# @@protoc_insertion_point(module_scope)
